@@ -865,9 +865,9 @@ class Database(object):
         self.reopen()
         def op():
             qp = self.prepare_query_parser(language)
-            return qp.parse_query(query, QueryParser.FLAG_SPELLING_CORRECTION)
-        self.retry_if_modified(op, retry_limit)
-        return qp.get_corrected_query_string().decode('utf8')
+            qp.parse_query(query, QueryParser.FLAG_SPELLING_CORRECTION)
+            return qp.get_corrected_query_string().decode('utf8')
+        return self.retry_if_modified(op, retry_limit)
 
     def suggest(self, query,
                 offset=0,
